@@ -1,13 +1,11 @@
 package WWW::Curl::Easy;
 
-use strict;
-use warnings;
 use WWW::Curl ();
 use Net::Curl::Easy ();
 use Exporter ();
 our @ISA = qw(Net::Curl::Easy Exporter);
 
-our $VERSION = 4.15;
+our $VERSION = '4.15';
 our @EXPORT;
 
 BEGIN {
