@@ -1,7 +1,4 @@
 package WWW::Curl::Share;
-
-use strict;
-use warnings;
 use WWW::Curl ();
 use Net::Curl::Share ();
 use Exporter ();
